#this script was adopted the R script of MEGASAT software
library(ggplot2)

multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  require(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

#depth: depth output file resulted from SSRGeno
#genotype: genotype output file resulted from SSRGeno, or manually curated genotypes file, the file contained 4 columns with a header line, the first column is No. of MRA(microsatellite repeat array), the second column is sample name, the third and fourth column is the allele of sample represented by length of MRA.
#out: output pdf file

DrawFig<-function(depth,genotype,threshold=50,out,width=15,height=25)
{


dat<-read.table(file=depth,header=T,sep="\t")
dat<-dat[which(dat$total_count>threshold),]
stack<-unique(dat$stack_id)
geno<-read.table(file=genotype,header=T,sep="\t")

fakedata <- data.frame(variable="0",value="0")
fakeplot <- ggplot(fakedata,aes(x=variable, y=value))+
  geom_point()+
  ylab("depth")+
  ggtitle("Placeholder")


pdf(file=out,width=width,height=height)


for(s in stack)
{

dat.s0<-dat[which(dat$stack_id==s),]

tt<-0
for(i in 5:dim(dat.s0)[2])
{
tt<-tt+length(which(dat.s0[,i]>threshold))
}

if(tt>0)
{

dat.s0<-dat.s0[order(dat.s0$Repeats),]

geno.s0<-geno[which(geno$stack==s),]

m<-0
plots<-list()
for(i in 5:dim(dat.s0)[2])
{
tmp<-dat.s0[,c(3,i)]

colnames(tmp)<-c("Repeats","Depth")
if(length(which(tmp$Depth>0))>4)
{
tmp<-tmp[which(tmp$Depth>0),]
}
tmp$Repeats<-factor(tmp$Repeats)
tmp$col<-NA
tmp$col[which(tmp$Depth<threshold)]<-"A"
tmp$col[which(tmp$Depth<threshold*1.15 & tmp$Depth>=threshold)]<-"B"
tmp$col[which(tmp$Depth>threshold*1.15)]<-"C"

colorScheme <- c("A" = "grey", "B" = "pink", "C" =  "deepskyblue", "D" ="dodgerblue4" ) 
tmp.geno<-geno.s0[which(geno.s0$samples==colnames(dat.s0)[i]),c(3,4)]
alleles<-paste(tmp.geno[,1],tmp.geno[,2],sep=",")
tmp$col[which(tmp$Repeats==as.character(tmp.geno[,1]))]<-"D"
tmp$col[which(tmp$Repeats==as.character(tmp.geno[,2])) ]<-"D"


xlab=paste("Repeat (Genotype:",alleles,")",sep="")
p<-ggplot(data=tmp,aes(x=Repeats,y=Depth,fill=col))+geom_bar(stat="identity",show.legend=F)+scale_fill_manual(values = colorScheme,breaks= c("A","B","C","D"))+xlab(xlab)+ylab("Depth")+ggtitle(paste("stack ",s,"\n",colnames(dat.s0)[i]))+theme(axis.text.x=element_text(angle=90,hjust=1))

if(m<32)
{
m<-m+1
plots[[m]]<-p
}
else
{
layout<-matrix(seq(length(plots)),ncol=4,byrow=T)
multiplot(plotlist=plots,layout=layout)
m=1
plots[[m]]<-p
}

}

while(m<32)
{
m<-m+1
plots[[m]]<-fakeplot
}
layout<-matrix(seq(length(plots)),ncol=4,byrow=T)
multiplot(plotlist=plots,layout=layout)

}

}


dev.off()


}

